summaryrefslogtreecommitdiffstats
path: root/kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h')
-rw-r--r--kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h b/kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h
index 9eb6060d..be93fea5 100644
--- a/kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h
+++ b/kspread/plugins/insertcalendar/kspread_plugininsertcalendar.h
@@ -29,7 +29,7 @@
#include <koffice_export.h>
-#include <qdatetime.h>
+#include <tqdatetime.h>
class KAboutData;
@@ -52,11 +52,12 @@ class InsertCalendarDialog;
class KSPREAD_EXPORT PluginInsertCalendar : public KParts::Plugin
{
Q_OBJECT
+ TQ_OBJECT
protected:
/**
* This is the parent part of the plugin. It is used
* to access the spreadsheet and actually insert the
* calendar.
*
@@ -77,7 +78,7 @@ class KSPREAD_EXPORT PluginInsertCalendar : public KParts::Plugin
/**
* Constructor. This constructor is usable with KGenericFactory.
*/
- PluginInsertCalendar( QObject *parent, const char *name, const QStringList& args );
+ PluginInsertCalendar( TQObject *tqparent, const char *name, const TQStringList& args );
/**
* Virtual destructor.
@@ -105,7 +106,7 @@ class KSPREAD_EXPORT PluginInsertCalendar : public KParts::Plugin
* from the insert calendar dialog and builds an calendar in the
* spreadsheet accordingly.
*/
- void slotInsertCalendar(const QDate &start, const QDate &end);
+ void slotInsertCalendar(const TQDate &start, const TQDate &end);
};
}
@@ -52,11 +52,12 @@ class InsertCalendarDialog;
protected:
/**
- * This is the parent part of the plugin. It is used
+ * This is the tqparent part of the plugin. It is used
* to access the spreadsheet and actually insert the
* calendar.